@@ -2,14 +2,17 @@ use rulex_macro::rulex;
 
 #[test]
 fn rust() {
-    const REGEX: &str = rulex!(r" 'foo' | 'bar'? ");
+    const REGEX: &str = rulex!("foo" | "bar"?);
 
     assert_eq!(REGEX, "foo|(?:bar)??");
 }
 
 #[test]
 fn pcre() {
-    const REGEX: &str = rulex!(r#" 'foo' (!>> 'bar') "#, flavor = Pcre);
+    const REGEX: &str = rulex!(
+        #flavor = Pcre
+        "foo" (!>> "bar")
+    );
 
     assert_eq!(REGEX, "foo(?!bar)");
 }
